from setuptools import setup, find_packages
from setuptools.command.install import install
import os
import requests

VERSION_FILE = "krakenparser/version.py"

class CustomInstallCommand(install):
    """Custom installation to download KEGG_decoder.py."""
    def run(self):
        # Run standard installation
        install.run(self)

        # Define where to download the script
        install_dir = os.path.join(self.install_lib, "krakenparser")  # Adjust if needed
        os.makedirs(install_dir, exist_ok=True)  # Ensure the directory exists

        # Define the script URL and target path
        combine_mpa_url = "https://raw.githubusercontent.com/jenniferlu717/KrakenTools/refs/heads/master/combine_mpa.py"
        combine_mpa_path = os.path.join(install_dir, "combine_mpa.py")

        # Download the script
        print(f"Downloading {combine_mpa_url} to {combine_mpa_path}...")
        try:
            response = requests.get(combine_mpa_url, timeout=10)
            response.raise_for_status()  # Raise an error for bad status codes
            with open(combine_mpa_path, "wb") as f:
                f.write(response.content)
            print(f"Successfully downloaded {combine_mpa_path}")
        except requests.RequestException as e:
            print(f"Failed to download {combine_mpa_url}: {e}")

        # Define the script URL and target path
        kreport2mpa_url = "https://raw.githubusercontent.com/jenniferlu717/KrakenTools/refs/heads/master/kreport2mpa.py"
        kreport2mpa_path = os.path.join(install_dir, "kreport2mpa.py")

        # Download the script
        print(f"Downloading {kreport2mpa_url} to {kreport2mpa_path}...")
        try:
            response = requests.get(kreport2mpa_url, timeout=10)
            response.raise_for_status()  # Raise an error for bad status codes
            with open(kreport2mpa_path, "wb") as f:
                f.write(response.content)
            print(f"Successfully downloaded {kreport2mpa_path}")
        except requests.RequestException as e:
            print(f"Failed to download {kreport2mpa_url}: {e}")

version = {}
with open(VERSION_FILE) as f:
    exec(f.read(), version)

setup(
    name="KrakenParser",
    version=version["__version__"],
    description="A collection of scripts designed to process Kraken2 reports and convert them into CSV format.",
    long_description=open("README_PyPI.md").read(),
    long_description_content_type="text/markdown",
    author="Ilia Popov",
    author_email="iljapopov17@gmail.com",
    url="https://github.com/PopovIILab/KrakenParser",
    packages=find_packages(),
    include_package_data=True,  # Ensure non-Python files are included
    package_data={
        "krakenparser": ["*.sh"],  # Include all .sh scripts inside krakenparser/
    },
    cmdclass={"install": CustomInstallCommand},
    entry_points={
        "console_scripts": [
            "KrakenParser=krakenparser:krakenparser.main",  # Maps the command to the main function
        ],
    },
    install_requires=open("requirements.txt").read().splitlines(),
    python_requires=">=3.6",
)